<?php

define( 'POSITIVE_CARDINAL_NUMBER' , 0 );
define( 'NATURAL_NUMBER' , 1 );
define( 'EMAIL_ADDRESS' , 2 );
define( 'DATE_WITHOUT_TIME' , 3 );
define( 'CHECKBOX' , 4 );
define( 'INTEGER_NUMBER' , 5 );
define( 'NOT_NULL_STRING', 6 );
define( 'DATE_WITH_TIME' , 7 );
define('TIME_HOUR_MINUTE', 8);

class Verifier
{
	function verify( $dataType , $value , $defaultValue = NULL )
	{
		switch( $dataType )
		{
			case POSITIVE_CARDINAL_NUMBER:
				return preg_match( '/^[0-9]\d*$/' , $value ) ? $value : $defaultValue;
			
			case NATURAL_NUMBER:
				return preg_match( '/^\d+$/' , $value ) ? $value : $defaultValue;

			case EMAIL_ADDRESS:				
				//return preg_match('/\b[A-Z0-9._%-]+@[A-Z0-9.-]+\.[A-Z]{2,4}\b/', $value) ? $value : $defaultValue;
				return $value;
			
			case TIME_HOUR_MINUTE:
				if ( 
					is_array( $value ) 

					&& isset( $value['m'] ) && isset( $value['h'] )
				) {	
					$h = $value['h'];
					$m = $value['m'];					
					if ($h < 24 & $m < 60) {
						return ($h < 10 ? "0$h" : $h) . ':' . ($m < 10 ? "0$m" : $m);
					}
					return $defaultValue;
				} 
				break;	

			case DATE_WITHOUT_TIME:
				if ( 
					is_array( $value ) 
					&& isset( $value['Y'] ) && isset( $value['m'] )
				) {	
					$Y = $value['Y'];
					$m = $value['m'];
					$d = empty( $value['d'] ) ? '1' : $value['d'];
					return checkdate( $m , $d , $Y ) ? "$Y-$m-" . ( $d > 9 ? $d : "0$d" ) : $defaultValue;
				} elseif ( preg_match( '/^(\d\d\d\d)-(\d\d)-(\d\d)$/' , $value , $preg_out ) )
					return checkdate( $preg_out[2] , $preg_out[3] , $preg_out[1] ) ? $value : $defaultValue;
				else
					return $defaultValue;

			case DATE_WITH_TIME:
				if( preg_match( '/^(\d\d\d\d)-(\d\d)-(\d\d)( (\d\d):(\d\d))?$/' , $value , $preg_out ) ) {
					return checkdate( $preg_out[2] , $preg_out[3] , $preg_out[1] ) ? $value : $defaultValue;
				} else {
					return $defaultValue;
				}

			case CHECKBOX:
				return $value == 'on' ? 'on' : $defaultValue;
				
			case INTEGER_NUMBER:
				return preg_match( '/^-?\d+$/' , $value ) ? $value : $defaultValue;

			case NOT_NULL_STRING:
				return $value != '' ? $value : $defaultValue;
				
			default:
				return $defaultValue;
		}
	}

	function verifyFromREQUEST( $dataType , $indexInREQUESTArray , $defaultValue = NULL )
	{
		return Verifier::verifyFromArray( $dataType , $indexInREQUESTArray , $_REQUEST , $defaultValue );
	}
	
	function verifyFromArray( $dataType , $indexInArray , &$array , $defaultValue = NULL )
	{
		switch( true ) {
			case is_array( $indexInArray ):
				$ret = array();
				foreach( $indexInArray as $key ) {
					$val = Verifier::verifyFromArray( $dataType, $key, $indexInArray, null );
					$ret[ $key ] = $val;	
				}
				return $ret;
		
			case isset( $array[ $indexInArray ] ):
				return Verifier::verify( $dataType , $array[ $indexInArray ] , $defaultValue );

			default:
				return $defaultValue;
		}
	}
		
}